# MeanFi authors

## Current meanfi maintainers
- Kostas Vilkelis
- R. Johanna Zijderveld
- Anton R. Akhmerov
- Antonio L.R. Manesco

## Other contributors
- Isidora Araya Day
- José L. Lado

## Funding

The project was developed in [Delft University of
Technology](https://www.tudelft.nl/en/).
We acknowledge funding from the European Research Council (ERC) under the European Union’s Horizon 2020 research and innovation program grant agreement No. 828948
(AndQC) and [Netherlands
Organisation for Scientific Research (NWO/OCW)](https://www.nwo.nl/) 016.Vidi.189.180 grant.
